# Gen-All

CLI Tool to generate Python `__init__.py` files with members specified in `__all__`.

Often times I want to add all non-private objects to the dunder-init file (or all minus a select few). But it can be annonying when you have multiple dunder-init files or want to keep the dunder-all up to date.
